@@ -20,15 +20,12 @@
 #include <QMovie>
 
 BehaviorConfig_Events::BehaviorConfig_Events(QWidget *parent)
-	: QWidget(parent)
+    : QWidget(parent)
 {
-	setupUi(this);
+    setupUi(this);
 
-	if ( !QMovie::supportedFormats().contains("mng") )
-	{
-		kcfg_trayflashNotify->setEnabled(false);
-		kcfg_trayflashNotify->setToolTip(i18n("Animation is not possible as your Qt version does not support the mng video format."));
-	}
+    if (!QMovie::supportedFormats().contains("mng")) {
+        kcfg_trayflashNotify->setEnabled(false);
+        kcfg_trayflashNotify->setToolTip(i18n("Animation is not possible as your Qt version does not support the mng video format."));
+    }
 }
-
-#include "behaviorconfig_events.moc"
